@@ -8,6 +8,7 @@ class Help;
 class Caps;
 class Resistors;
 class Calculations;
+class Netcable;
 
 namespace Ui {
     class MainWindow;
@@ -48,6 +49,8 @@ private slots:
 
     void on_pushButtonColors_clicked();
 
+    void on_pushButtonNetcable_clicked();
+
 private:
     Ui::MainWindow *ui;
     About *about;
@@ -55,6 +58,7 @@ private:
     Caps *caps;
     Resistors *resistors;
     Calculations *calculations;
+    Netcable *netcable;
 };
 
 #endif // MAINWINDOW_H
