@@ -20,9 +20,12 @@ public slots:
 
 protected:
     void changeEvent(QEvent *e);
+    void resizeEvent(QResizeEvent *event);
 
 private:
     Ui::Resistors *ui;
+    bool portrait;
+    bool fiveBand;
 
     QIcon createIcon(QString colorName);
 };
